@@ -1,6 +1,7 @@
 /* FIGARO'S PASSWORD MANAGER (FPM)
  * Copyright (C) 2000 John Conneely
- * 
+ * Copyright (C) 2008,2009 Aleš Koval
+ *
  * FPM is open source / free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -20,10 +21,6 @@
 
 #include <gtk/gtk.h>
 
-void
-on_preferences1_activate               (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
 void
 on_about1_activate                     (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
@@ -159,11 +156,11 @@ on_entry_password_activate             (GtkEditable     *editable,
 void
 on_button_cpw_ok_clicked               (GtkButton       *button,
                                         gpointer         user_data);
-
+/*
 void
 on_button_cpw_cancel_clicked           (GtkButton       *button,
                                         gpointer         user_data);
-
+*/
 
 void
 on_copy_pass_activate                  (GtkMenuItem     *menuitem,
@@ -193,11 +190,6 @@ void
 on_button_change_cat_clicked           (GtkButton       *button,
                                         gpointer         user_data);
 
-gboolean
-on_dialog_prefs_destroy_event          (GtkWidget       *widget,
-                                        GdkEvent        *event,
-                                        gpointer         user_data);
-
 void
 on_dialog_prefs_destroy                (GtkObject       *object,
                                         gpointer         user_data);
@@ -210,14 +202,14 @@ void
 on_import_passwords1_activate          (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
-void
+/*void
 on_button_import_ok_clicked            (GtkButton       *button,
                                         gpointer         user_data);
 
 void
 on_button_import_cancel_clicked        (GtkButton       *button,
                                         gpointer         user_data);
-
+*/
 void
 on_current_password_file1_activate     (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
@@ -414,3 +406,153 @@ on_find_entry_activate                 (GtkEntry        *entry,
 void
 on_find_match_case_toggled             (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
+
+void
+tray_icon_on_click			(GtkStatusIcon *status_icon, 
+					 gpointer user_data);
+
+void
+tray_icon_on_menu			(GtkStatusIcon *status_icon, guint button, 
+					 guint activate_time, gpointer user_data);
+
+void
+on_enable_tray_icon_toggled            (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_lock1_activate                      (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_tr_auto_hide_toggled                (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_tr_auto_lock_toggled                (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_hide_to_tray_activate               (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+gboolean
+on_app_safe_window_state_event         (GtkWidget       *widget,
+                                        GdkEventWindowState	*event,
+                                        gpointer         user_data);
+
+void
+on_show1_activate                      (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+
+gboolean
+on_app_safe_focus_in_event             (GtkWidget       *widget,
+                                        GdkEventFocus   *event,
+                                        gpointer         user_data);
+
+gboolean
+on_app_safe_focus_out_event            (GtkWidget       *widget,
+                                        GdkEventFocus   *event,
+                                        gpointer         user_data);
+
+void
+on_unlock1_activate                    (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+gboolean
+on_toolbar1_popup_context_menu         (GtkToolbar      *toolbar,
+                                        gint             arg1,
+                                        gint             arg2,
+                                        gint             arg3,
+                                        gpointer         user_data);
+
+void
+on_icons_and_text1_activate            (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_icons_only1_activate                (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_text_only1_activate                 (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_hide_toolbar1_activate              (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_startup_category_toggled            (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+void
+on_startup_category_combo_changed      (GtkComboBox     *combobox,
+                                        gpointer         user_data);
+
+void
+on_toolbar2_activate                   (GtkCheckMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+gboolean
+on_button_cpw_cancel_clicked           (GtkWidget       *widget,
+                                        GdkEvent        *event,
+                                        gpointer         user_data);
+void
+on_select_key_file_clicked             (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_dialog_edit_passitem_destroy        (GtkObject       *object,
+                                        gpointer         user_data);
+
+/*void
+on_optionmenu_launcher_changed         (GtkComboBox     *combobox,
+                                        gpointer         user_data);
+*/
+void
+on_copy_target_combo_changed        (GtkComboBox     *combobox,
+                                        gpointer         user_data);
+
+void
+on_new_file_activate                   (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_combo_entry_launcher_changed        (GtkComboBox     *combobox,
+                                        gpointer         user_data);
+
+void
+on_btn_launcher_remove_clicked         (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_btn_launcher_add_clicked            (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_btn_launcher_apply_clicked          (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+dialog_launcher_destroy                (GtkObject       *object,
+                                        gpointer         user_data);
+
+void
+on_btn_launcher_close_clicked          (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_copy_both1_activate                 (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_btn_show_key_file_clicked           (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_launcher_menu_activate              (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_clone_item1_activate                (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
